%global modname velruse

Name:           python-%{modname}
Version:        1.1.1
Release:        5%{?dist}
Summary:        Simplify third-party authentication for web applications

Group:          Development/Libraries
License:        MIT
URL:            http://pypi.python.org/pypi/%{modname}
Source0:        http://pypi.python.org/packages/source/v/%{modname}/%{modname}-%{version}.tar.gz
# https://github.com/bbangert/velruse/pull/134
Patch0:         python-velruse-extract-extra-data.patch

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python-setuptools

BuildRequires:  python-openid
BuildRequires:  python-oauth2
BuildRequires:  python-pyramid
BuildRequires:  python-requests
BuildRequires:  python-anykeystore

# No test dependencies are installed since they require python-selenium
# We don't run the tests.

Requires:       python-openid
Requires:       python-oauth2
Requires:       python-pyramid
Requires:       python-requests
Requires:       python-anykeystore
Requires:       python-requests-oauthlib


%description
Velruse is a set of authentication routines that provide a unified way
to have a website user authenticate to a variety of different identity
providers and/or a variety of different authentication schemes.

It is similar in some ways to Janrain Engage with the exception of being
open-source, locally installable, and easily pluggable for custom identity
providers and authentication schemes.

You can run Velruse as a stand-alone service for use with your websites
regardless of the language they’re written in. While Velruse itself is
written in Python, since it can interact with your website purely via HTTP
POST’s.

Velruse can:

 - Normalize identity information from varying provider sources (OpenID,
   Google, Facebook, etc.) to Portable Contacts.
 - Simplify complex authentication protocols by providing a simple
   consistent API
 - Provide extension points for other authentication systems, write your
   own auth provider to handle CAS, LDAP, and use it with ease
 - Integrate with most web applications regardless of the language used to
   write the website

Velruse aims to simplify authenticating a user. It provides auth provider‘s
that handle authenticating to a variety of identity providers with multiple
authentication schemes (LDAP, SAML, etc.). Eventually, Velruse will include
widgets similar to RPXNow that allow one to customize a login/registration
widget so that a website user can select a preferred identity provider to
use to sign-in. In the mean-time, effort is focused on increasing the
available auth provider‘s for the commonly used authentication schemes and
identity providers (Facebook, Google, OpenID, etc). Unlike other
authentication libraries for use with web applications, a website using
Velruse for authentication does not have to be written in any particular
language.

%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1

# Remove bundle egg info in case it exists
rm -rf %{modname}.egg-info

%build
%{__python} setup.py build

%install
%{__python} setup.py install -O1 --skip-build --root=%{buildroot}

%check
# No tests are run since they require python-selenium

%files
%doc PKG-INFO
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}*

%changelog
* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 23 2015 Ralph Bean <rbean@redhat.com> - 1.1.1-1
- Latest upstream.

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Oct 17 2013 Ralph Bean <rbean@redhat.com> - 1.0.3-6
- Apply patch introducing an new extension point

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 28 2012 Ralph Bean <rbean@redhat.com> - 1.0.3-3
- Added forgotten dependencies.
* Sun Nov 11 2012 Ralph Bean <rbean@redhat.com> - 1.0.3-2
- Remove bundled egg-info in %%prep.
* Thu Nov 08 2012 Ralph Bean <rbean@redhat.com> - 1.0.3-1
- Initial packaging for fedora.
